<?php
if (!class_exists('EmailsTpl_Emails'))
{
	class EmailsTpl_Emails
	{
		/**
		 * The name of table in the DB
		 * @static
		 * @var string
		 */
		static $table_name = 'emails_templates';
		
		/**
		 * Add templates
		 * 
		 * @static
		 * @param array $data with all the key/values to be added to table
		 * @return int|bool ID generated for an AUTO_INCREMENT column by the most recent INSERT query 
		 * 					or FALSE when the query wasn't executed succesfully
		 * @access public
		 */
		static public function add_template($data)
		{
			// Only add wildcard if aren't in database
			$already = self::get($data['name'],'name','%s');
			
			if ($already!='')
				return FALSE;
			else 
				return self::add($data);
		}
		
		/**
		 * Send emails
		 * 
		 * This will be used by others plugins.
		 *
		 * @static 
		 * @param string $email_template_name name of the template in database
		 * @param array $keywords_value with all the key/values to replace the related keywords of email 
		 * 								template with this values
		 * @param string $to the recipient
		 * @param string $lang the language to get the translation of the template
		 * @param string $type the type of the email to send, can be: 'html' and 'plaintext'
		 * @access public
		 */
		static function send_email($email_template_name,$keywords_value=array(),$to,$lang='',$type='html') 
		{
			// Get all translations for that template, order by ID, so the first template is the default
			$email_template_data_arr = self::get_all($email_template_name,'name','id','%s');
			
			// Send only if there is a template specified
			if (count($email_template_data_arr)>0) {
				
				// Set data of the firts email
				$email_template_data = $email_template_data_arr[0];
				
				// set data for the selected language, if any
				foreach ($email_template_data_arr as $item) {
					if (strtolower($item->lang)==strtolower($lang))
						$email_template_data = $item;
				}
				
				// get subject and body
				$subject = $email_template_data->subject;
				$body = $email_template_data->body;
				
				// Replace all default keywords in subject and body 
				// [site_url] Used the WordPress function to retreive this value
				$site_url = get_bloginfo('url');
				$subject = str_replace("[site_url]",$site_url,$subject);
				$body = str_replace("[site_url]",$site_url,$body);
				// [site_name] Used the WordPress function to retreive this value
				$site_name = get_bloginfo('name');
				$subject = str_replace("[site_name]",$site_name,$subject);
				$body = str_replace("[site_name]",$site_name,$body);
				
				// Replace all keys passed in subject and body
				foreach ($keywords_value as $key=>$value) {
					$subject = str_replace("[$key]",$value,$subject);
				}
				foreach ($keywords_value as $key=>$value) {
					$body = str_replace("[$key]",$value,$body);
				}
				
				// Set headers
				$headers = "X-Mailer: PHP" . phpversion() . "\n";
			
				// Sanitization of subject and body
				$subject = stripslashes($subject);
				$body = stripslashes($body);
				
				// Set headers and do sanitization in depends on type of email
				if ($type=='html') {
					$headers .= "MIME-Version: 1.0\n";
					$headers .= "Content-Type: " . get_bloginfo('html_type') . "; charset=\"". get_bloginfo('charset') . "\"\n";
					$mailtext = "<html><head><title>" . $subject . "</title></head><body>" . $body . "</body></html>";
				} else {
					$headers .= "MIME-Version: 1.0\n";
					$headers .= "Content-Type: text/plain; charset=\"". get_bloginfo('charset') . "\"\n";
					$body = preg_replace('|&[^a][^m][^p].{0,3};|', '', $body);
					$body = preg_replace('|&amp;|', '&', $body);
					$mailtext = wordwrap(strip_tags($body), 80, "\n");
				}
				
				// Set final headers
				$headers .= "To: \"" . "\" <" . $to . ">\n";
				///var_dump($to. $subject. $mailtext. $headers);//TODO: when finish, remove this test line
				// Send email with WordPress function
				wp_mail($to, $subject, $mailtext, $headers);
			}
		}
		
		/*
		 * except "EmailsTpl" that is the name of the class of the plugin
		 * Begin Common Code
		 * This can be avoid since PHP 5.3 (http://www.php.net/manual/en/language.oop5.late-static-bindings.php)
		 */
		
		/**
		 * The Object to access DB
		 * @static
		 * @var GpcKits_DBO
		 */
		static $db_obj;
		
		/**
		 * Set DB Object
		 *
		 * @static 
		 * @global $wpdb used to access to WordPress Object that manage DB
		 * @param string $table optional value of the table
		 * @access public
		 */
		static public function set_db_obj($table='')
		{
		   	global $wpdb;
		   	if ($table=='') $table = self::$table_name;
		   	$full_table_name =  $wpdb->prefix . EmailsTpl::$db_prefix . $table;
		   	
		   	if (class_exists('GpcKits_DBO'))
				self::$db_obj = new GpcKits_DBO($full_table_name);
		}
		
		/**
		 * Get all items from DB
		 * 
		 * @static
		 * @param int $id value of the field to filter
		 * @param string $field name of the column to filter
		 * @param string $order_by name of the column to order by
		 * @param string $field_type type of the column to filter (can be '%s' for strings or '%d' for numeric values)
		 * @return array
		 * @access public
		 */
		static public function get_all($id='', $field='', $order_by='', $field_type='')
		{
	   		self::set_db_obj();
	   		if (self::$db_obj!=NULL)
	   			return self::$db_obj->get_all($id, $field, $order_by, $field_type);
	   		else
	   			return array();
		}
		
		/**
		 * Get item from DB
		 * 
		 * @static
		 * @param int $id value of the field to filter
		 * @param string $field name of the column to filter
		 * @param string $field_type type of the column to filter (can be '%s' for strings or '%d' for numeric values)
		 * @return array|NULL data when query was executed succesfully, else return NULL
		 * @access public
		 */
		static public function get($id, $field='', $field_type='')
		{
			self::set_db_obj();
			if (self::$db_obj!=NULL)
	   			return self::$db_obj->get($id, $field, $field_type);
	   		else
	   			return NULL;
		}
		
		/**
		 * Update item DB
		 * 
		 * @static
		 * @param array $data with all the key/values to be updated in the table
		 * @param array $where with all the key/values to filter the update
		 * @return bool true when query was executed succesfully, else return FALSE
		 * @access public
		 */
		static public function update($data,$where)
		{
		   	self::set_db_obj();
		   	if (self::$db_obj!=NULL)
	   			return self::$db_obj->update($data,$where);
	   		else 
	   			return FALSE;
		}
		
		/**
		 * Add item DB
		 * 
		 * @static
		 * @param array $data with all the key/values to be added to table
		 * @return int|bool ID generated for an AUTO_INCREMENT column by the most recent INSERT query 
		 * 					or FALSE when the query wasn't executed succesfully
		 * @access public
		 */
		static public function add($data)
		{
			self::set_db_obj();
			if (self::$db_obj!=NULL)
	   			return self::$db_obj->add($data);
	   		else 
	   			return FALSE;
		}
		
		/**
		 * Delete item DB
		 * 
		 * @static
		 * @param int $id value of the field of the data to delete
		 * @param string $field name of the column to filter
		 * @param string $field_type type of the column to filter (can be '%s' for strings or '%d' for numeric values)
		 * @return bool true when query was executed succesfully, else return FALSE
		 * @access public
		 */
		static public function delete($id, $field='', $field_type='')
		{
			self::set_db_obj();
			if (self::$db_obj!=NULL)
	   			return self::$db_obj->delete($id,$field,$field_type);
	   		else 
	   			return FALSE;
		}
		
		/*
		 * End Common Code
		 * This can be avoid since PHP 5.3 (http://www.php.net/manual/en/language.oop5.late-static-bindings.php)
		 */
	}
}
?>